]> granicus.if.org Git - neomutt/commitdiff
globals: upper case
authorRichard Russon <rich@flatcap.org>
Sun, 9 Dec 2018 15:07:21 +0000 (15:07 +0000)
committerRichard Russon <rich@flatcap.org>
Sun, 9 Dec 2018 16:00:53 +0000 (16:00 +0000)
16 files changed:
compress.c
compress.h
imap/imap.c
imap/imap.h
maildir/lib.h
maildir/maildir.c
maildir/mh.c
mbox/mbox.c
mbox/mbox.h
mx.c
nntp/nntp.c
nntp/nntp.h
notmuch/mutt_notmuch.c
notmuch/mutt_notmuch.h
pop/pop.c
pop/pop.h

index df198fb132e22f8c80f17e13c8f37daf7a879afc..9e13bbc919028b256e86fe2502bfac453882d151 100644 (file)
@@ -987,12 +987,12 @@ int comp_path_parent(char *buf, size_t buflen)
 
 // clang-format off
 /**
- * struct mx_comp_ops - Compressed mailbox - Implements ::MxOps
+ * MxCompOps - Compressed mailbox - Implements ::MxOps
  *
  * Compress only uses open, close and check.
  * The message functions are delegated to mbox.
  */
-struct MxOps mx_comp_ops = {
+struct MxOps MxCompOps = {
   .magic            = MUTT_COMPRESSED,
   .name             = "compressed",
   .ac_find          = comp_ac_find,
index f0e6bb71d1c4625a52eabb97b536c472d045d2db..d5e0b9530a4e03465f5c12390389b22732530b9c 100644 (file)
@@ -50,6 +50,6 @@ bool mutt_comp_can_read(const char *path);
 int mutt_comp_valid_command(const char *cmd);
 int comp_path_probe(const char *path, const struct stat *st);
 
-extern struct MxOps mx_comp_ops;
+extern struct MxOps MxCompOps;
 
 #endif /* MUTT_COMPRESS_H */
index 54a3cc85f8af89fc541e2a9791d97132d3f4778c..e245323bf0503bde9ecad3fbab0ec9bb4c382904 100644 (file)
@@ -2539,9 +2539,9 @@ int imap_path_parent(char *buf, size_t buflen)
 
 // clang-format off
 /**
- * struct mx_imap_ops - IMAP mailbox - Implements ::MxOps
+ * MxImapOps - IMAP mailbox - Implements ::MxOps
  */
-struct MxOps mx_imap_ops = {
+struct MxOps MxImapOps = {
   .magic            = MUTT_IMAP,
   .name             = "imap",
   .ac_find          = imap_ac_find,
index 5f7fc5213a9810bdccbdeced1562c45632a18b15..2693f1c1bd6a5bef8f2c0186fa54845561efc66b 100644 (file)
@@ -89,7 +89,7 @@ int imap_fast_trash(struct Mailbox *m, char *dest);
 int imap_path_probe(const char *path, const struct stat *st);
 int imap_path_canon(char *buf, size_t buflen);
 
-extern struct MxOps mx_imap_ops;
+extern struct MxOps MxImapOps;
 
 /* browse.c */
 int imap_browse(char *path, struct BrowserState *state);
index cb180a2dbb9260a51f5d6ded30f88761f5e3613e..57f3c5f1e68c38aced438c19a59b6429fee9291e 100644 (file)
@@ -54,8 +54,8 @@ extern char *MhSeqFlagged;
 extern char *MhSeqReplied;
 extern char *MhSeqUnseen;
 
-extern struct MxOps mx_maildir_ops;
-extern struct MxOps mx_mh_ops;
+extern struct MxOps MxMaildirOps;
+extern struct MxOps MxMhOps;
 
 int           maildir_check_empty      (const char *path);
 void          maildir_gen_flags        (char *dest, size_t destlen, struct Email *e);
index 93cd615f4d08f13248dd5595ad5dc357af13e8e8..9dfd3de434aa22a3240ab6a54cf19bddfaa2958e 100644 (file)
@@ -679,9 +679,9 @@ enum MailboxType maildir_path_probe(const char *path, const struct stat *st)
 
 // clang-format off
 /**
- * struct mx_maildir_ops - Maildir mailbox - Implements ::MxOps
+ * MxMaildirOps - Maildir mailbox - Implements ::MxOps
  */
-struct MxOps mx_maildir_ops = {
+struct MxOps MxMaildirOps = {
   .magic            = MUTT_MAILDIR,
   .name             = "maildir",
   .ac_find          = maildir_ac_find,
index 2974f58630e38973c15ac85e9ec5303f1ec283c3..6708b87f6b3cc42de256de3b3e4eecef2d85ce75 100644 (file)
@@ -798,9 +798,9 @@ enum MailboxType mh_path_probe(const char *path, const struct stat *st)
 
 // clang-format off
 /**
- * struct mx_mh_ops - MH mailbox - Implements ::MxOps
+ * MxMhOps - MH mailbox - Implements ::MxOps
  */
-struct MxOps mx_mh_ops = {
+struct MxOps MxMhOps = {
   .magic            = MUTT_MH,
   .name             = "mh",
   .ac_find          = maildir_ac_find,
index 76456ad4b8ce5737125fdea4864b177dd6ececc4..c62bf3731f7ec516198df24379804e7c4daefbe6 100644 (file)
@@ -1835,9 +1835,9 @@ static int mbox_mbox_check_stats(struct Mailbox *m, int flags)
 
 // clang-format off
 /**
- * struct mx_mbox_ops - Mbox mailbox - Implements ::MxOps
+ * MxMboxOps - Mbox mailbox - Implements ::MxOps
  */
-struct MxOps mx_mbox_ops = {
+struct MxOps MxMboxOps = {
   .magic            = MUTT_MBOX,
   .name             = "mbox",
   .ac_find          = mbox_ac_find,
@@ -1862,9 +1862,9 @@ struct MxOps mx_mbox_ops = {
 };
 
 /**
- * struct mx_mmdf_ops - MMDF mailbox - Implements ::MxOps
+ * MxMmdfOps - MMDF mailbox - Implements ::MxOps
  */
-struct MxOps mx_mmdf_ops = {
+struct MxOps MxMmdfOps = {
   .magic            = MUTT_MMDF,
   .name             = "mmdf",
   .ac_find          = mbox_ac_find,
index 8ff31e8fd0a51ab632023c3117a35c9096495e67..ee2d85a185643c2409a25198cf89d831d20eec94 100644 (file)
@@ -51,8 +51,8 @@ struct MboxAccountData
   bool append : 1; /**< mailbox is opened in append mode */
 };
 
-extern struct MxOps mx_mbox_ops;
-extern struct MxOps mx_mmdf_ops;
+extern struct MxOps MxMboxOps;
+extern struct MxOps MxMmdfOps;
 
 #define MMDF_SEP "\001\001\001\001\n"
 
--- a/pop/pop.h
+++ b/pop/pop.h
@@ -51,7 +51,7 @@ extern bool  PopAuthTryAll;
 /* These Config Variables are only used in pop/pop_lib.c */
 extern unsigned char PopReconnect;
 
-extern struct MxOps mx_pop_ops;
+extern struct MxOps MxPopOps;
 
 void pop_fetch_mail(void);
 int pop_path_probe(const char *path, const struct stat *st);
diff --git a/mx.c b/mx.c
index 2f958377d9f3923c0911010c34651967a437f775..4405ce2ae79ad8d18f6440d81686cfa207ff40e7 100644 (file)
--- a/mx.c
+++ b/mx.c
@@ -99,27 +99,27 @@ char *Trash;        ///< Config: Folder to put deleted emails
 static const struct MxOps *mx_ops[] = {
 /* These mailboxes can be recognised by their Url scheme */
 #ifdef USE_IMAP
-  &mx_imap_ops,
+  &MxImapOps,
 #endif
 #ifdef USE_NOTMUCH
-  &mx_notmuch_ops,
+  &MxNotmuchOps,
 #endif
 #ifdef USE_POP
-  &mx_pop_ops,
+  &MxPopOps,
 #endif
 #ifdef USE_NNTP
-  &mx_nntp_ops,
+  &MxNntpOps,
 #endif
 
   /* Local mailboxes */
-  &mx_maildir_ops,
-  &mx_mbox_ops,
-  &mx_mh_ops,
-  &mx_mmdf_ops,
+  &MxMaildirOps,
+  &MxMboxOps,
+  &MxMhOps,
+  &MxMmdfOps,
 
 /* If everything else fails... */
 #ifdef USE_COMPRESSED
-  &mx_comp_ops,
+  &MxCompOps,
 #endif
   NULL,
 };
@@ -1442,23 +1442,23 @@ enum MailboxType mx_path_probe(const char *path, struct stat *st)
 
   static const struct MxOps *no_stat[] = {
 #ifdef USE_IMAP
-    &mx_imap_ops,
+    &MxImapOps,
 #endif
 #ifdef USE_NOTMUCH
-    &mx_notmuch_ops,
+    &MxNotmuchOps,
 #endif
 #ifdef USE_POP
-    &mx_pop_ops,
+    &MxPopOps,
 #endif
 #ifdef USE_NNTP
-    &mx_nntp_ops,
+    &MxNntpOps,
 #endif
   };
 
   static const struct MxOps *with_stat[] = {
-    &mx_maildir_ops, &mx_mbox_ops, &mx_mh_ops, &mx_mmdf_ops,
+    &MxMaildirOps, &MxMboxOps, &MxMhOps, &MxMmdfOps,
 #ifdef USE_COMPRESSED
-    &mx_comp_ops,
+    &MxCompOps,
 #endif
   };
 
index 22878b62510520aca0525e435773f02396ab6261..501fcf619e64ff61dafc8224013d7cc5caa2eb93 100644 (file)
@@ -2889,9 +2889,9 @@ int nntp_path_parent(char *buf, size_t buflen)
 
 // clang-format off
 /**
* struct mx_nntp_ops - NNTP mailbox - Implements ::MxOps
  */
-struct MxOps mx_nntp_ops = {
+struct MxOps MxNntpOps = {
   .magic            = MUTT_NNTP,
   .name             = "nntp",
   .ac_find          = nntp_ac_find,
index 1051e7c71465fe3d545e93321dab7337c6a39f9a..2d6b7244409601280b40f662721a32f88f71a000 100644 (file)
@@ -62,7 +62,7 @@ extern char *NewsCacheDir;
 extern char *Newsrc;
 
 extern struct NntpAccountData *CurrentNewsSrv;
-extern struct MxOps mx_nntp_ops;
+extern struct MxOps MxNntpOps;
 
 /* article number type and format */
 #define anum_t uint32_t
index ab1c64f6cb24b96a7d0813f7f67d91aa723a1e98..a90c0ccac8369c2d74943a934b2d82255e11db73 100644 (file)
@@ -2545,9 +2545,9 @@ int nm_path_parent(char *buf, size_t buflen)
 
 // clang-format off
 /**
* struct mx_notmuch_ops - Notmuch mailbox - Implements ::MxOps
  */
-struct MxOps mx_notmuch_ops = {
+struct MxOps MxNotmuchOps = {
   .magic            = MUTT_NOTMUCH,
   .name             = "notmuch",
   .ac_find          = nm_ac_find,
index 6eb27f0a2715bf30ebab5e50f5646335dae613d9..e1643f40a7144387ce3e86184cbed4f063322552 100644 (file)
@@ -54,7 +54,7 @@ extern char *NmUnreadTag;
 extern char *NmFlaggedTag;
 extern char *NmRepliedTag;
 
-extern struct MxOps mx_notmuch_ops;
+extern struct MxOps MxNotmuchOps;
 
 void  nm_db_debug_check             (struct Mailbox *m);
 int   nm_description_to_path     (const char *desc, char *buf, size_t buflen);
@@ -2889,9 +2889,9 @@ int nntp_path_parent(char *buf, size_t buflen)
 // clang-format off
 /**
- * struct mx_nntp_ops - NNTP mailbox - Implements ::MxOps
+ * MxNntpOps - NNTP mailbox - Implements ::MxOps
  */
@@ -2545,9 +2545,9 @@ int nm_path_parent(char *buf, size_t buflen)
 // clang-format off
 /**
- * struct mx_notmuch_ops - Notmuch mailbox - Implements ::MxOps
+ * MxNotmuchOps - Notmuch mailbox - Implements ::MxOps
  */
index cc0d9c49a943372a73341321490bffd8e035afbd..91718b21b1392f02fd5a813cac5b0b9c26e63b53 100644 (file)
--- a/pop/pop.c
+++ b/pop/pop.c
@@ -1276,9 +1276,9 @@ int pop_path_parent(char *buf, size_t buflen)
 
 // clang-format off
 /**
* mx_pop_ops - POP mailbox - Implements ::MxOps
  */
-struct MxOps mx_pop_ops = {
+struct MxOps MxPopOps = {
   .magic            = MUTT_POP,
   .name             = "pop",
   .ac_find          = pop_ac_find,
@@ -1276,9 +1276,9 @@ int pop_path_parent(char *buf, size_t buflen)
 // clang-format off
 /**
- * mx_pop_ops - POP mailbox - Implements ::MxOps
+ * MxPopOps - POP mailbox - Implements ::MxOps
  */
index bd14753daba6e857af476522c68f8ff8b5a27ad8..598e485f49aaa733c19ff2001aca90dff3c59107 100644 (file)